@@ -8,7 +8,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ('all' => [ qw(new get_info make_report)]);
 our @EXPORT_OK = (@{$EXPORT_TAGS{'all'}});
 our @EXPORT = qw();
-our $VERSION ='1.0';
+our $VERSION ='1.1';
 #####################################################
 my ($class, $this, $router);
 #####################################################
@@ -35,6 +35,8 @@ sub get_info(){
             if ($_ =~ /interface/){
              @split1 = split " ", $_;
              $interface = $split1[1];
+             $description = '';
+             $address = '';
             }
             if ($_ =~ /description/){
                 $description = $_;
